#! /bin/sh
#
# Script for reading toon room temperature values and storing them in a file.
# Data are stored on a daily basis: data for every day are put into a new file.
#
#   call: ./read_temp.sh outputfile_prefix
#
# The current date and .txt extension are added automatically.
#
#   example: ./read_temp.sh test- &
#
# will yield files like: test-20151222.txt (and runs in the background, 
# so you can close your shell without stopping the logging).
#
# note 1: Toon fills in UTC timestamps, please correct afterwards for your 
#         timezone.
#
# note 2: Toon temperature values have an offset of -6 degrees (variable 
#         i2cTempError, in the happ_thermstat code, default value -6.0),
#         or -6 degrees + your manually entered temperature correction. 
#         To get the actual values, please correct for this offset.
#	  
# note 3: Timing isn't really spot-on. The sleep command creates intervals, not 
#         accurately timed interrupts, so intervals between samples will be 
#         slightly larger.
#
# marcelr, 20151222, first draft.
#

# 
# temperature value files for toon (internally, toon uses the second file):
#
file0="/sys/devices/platform/imx-i2c.0/i2c-0/0-0048/device0/value"
file1="/sys/devices/platform/imx-i2c.0/i2c-0/0-0049/device1/value"

# set initial value for date cut-off (1 day + 1 second, to make sure it's used 
# in the very first loop iteration)
 
sec_day_old=86401

while true; do
    read -r line < "$file0"
    t0=$line
    read -r line < "$file1"
    t1=$line
    unix_time=`date +%s`
    sec_day=`expr $unix_time % 86400`

# construct output filename

    if [ "$sec_day" -lt "$sec_day_old" ]; then
	today="`date +%Y%m%d`"
	filename="$1-$today.txt"
    fi
    sec_day_old=$sec_day
	
    echo -e "$unix_time\t$t0\t$t1" >> $filename
    sleep 60
done